import { ArgumentsMapper, ClassType, OutputTypeFn } from "./graphq-compose-typescript";
import { ComposeOutputType, Resolver, ResolverWrapCb, SchemaComposer } from "graphql-compose";
import { StringKey } from "./utils";
import { ArgumentsBuilder, ParamsNamesKeeper } from "./arguments-builder";
import { QueueSolver } from "./type-composer-creation/queue-solver";
import { PropertyTypeConvertor } from "./argument-type-convertor";
import { SourceArgSpecKeeper } from "./resolver/source-arg-spec-keeper";
import { ContextSpecKeeper } from "./context/context-spec-keeper";
export declare const RESOLVER_SPECS: unique symbol;
export interface ResolverSpec {
    method: string;
    typeFn: OutputTypeFn;
}
export interface ClassWithResolversSpecs<T> extends ClassType<T> {
    [RESOLVER_SPECS]?: Map<StringKey<T>, ResolverSpec>;
}
export declare class ResolverSpecStorage {
    addResolverSpec<T>(constructor: ClassWithResolversSpecs<T>, method: StringKey<T>, typeFn: OutputTypeFn): void;
    getResolverSpec<T>(constructor: ClassWithResolversSpecs<T>, method: StringKey<T>): ResolverSpec;
}
export declare const WRAP_RESOLVER_SPEC: unique symbol;
export interface WrapResolverSpec<T> {
    method: StringKey<T>;
    wrapper: ResolverWrapCb<T, T, any>;
}
export interface ClassWithWrapSpecs<T> extends ClassType<T> {
    [WRAP_RESOLVER_SPEC]?: Map<StringKey<T>, WrapResolverSpec<T>[]>;
}
export declare class WrapResolverSpecStorage {
    addSpec<T>(constructor: ClassWithWrapSpecs<T>, method: StringKey<T>, wrapper: ResolverWrapCb<T, T, any>): void;
    getSpecs<T>(constructor: ClassWithWrapSpecs<T>, method: StringKey<T>): WrapResolverSpec<T>[];
}
export declare class ResolverBuilder {
    protected propertyTypeConvertor: PropertyTypeConvertor<ComposeOutputType<any, any>>;
    protected argumentsBuilder: ArgumentsBuilder;
    protected argumentsMapper: ArgumentsMapper;
    protected queueSolver: QueueSolver;
    protected storage: ResolverSpecStorage;
    protected paramsNamesKeeper: ParamsNamesKeeper;
    protected sourceArgSpecKeeper: SourceArgSpecKeeper;
    protected contextSpecKeeper: ContextSpecKeeper;
    protected schemaComposer: SchemaComposer<any>;
    protected wrapStorage: WrapResolverSpecStorage;
    constructor(propertyTypeConvertor: PropertyTypeConvertor<ComposeOutputType<any, any>>, argumentsBuilder: ArgumentsBuilder, argumentsMapper: ArgumentsMapper, queueSolver: QueueSolver, storage: ResolverSpecStorage, paramsNamesKeeper: ParamsNamesKeeper, sourceArgSpecKeeper: SourceArgSpecKeeper, contextSpecKeeper: ContextSpecKeeper, schemaComposer: SchemaComposer<any>, wrapStorage: WrapResolverSpecStorage);
    createResolver<T>(instance: T, method: StringKey<T>): Resolver<any, any, any>;
}
