import { InputTypeComposer, SchemaComposer, ObjectTypeComposer, EnumTypeComposer } from "graphql-compose";
import { TypeNameKeeper } from "../type-name";
import { ClassSpecialist, ClassType } from "../graphq-compose-typescript";
import { ComposerBuilder } from "./composer-builder";
import { ProvidenTypeSingular } from "./queue";
import { GraphqlComposeTypescriptError } from "../error";
export declare class ComposerCreator {
    protected outputCreator: ComposerInstanceCreator<ObjectTypeComposer>;
    protected inputCreator: ComposerInstanceCreator<InputTypeComposer>;
    protected outputBuilder: ComposerBuilder<ObjectTypeComposer>;
    protected inputBuilder: ComposerBuilder<InputTypeComposer>;
    constructor(outputCreator: ComposerInstanceCreator<ObjectTypeComposer>, inputCreator: ComposerInstanceCreator<InputTypeComposer>, outputBuilder: ComposerBuilder<ObjectTypeComposer>, inputBuilder: ComposerBuilder<InputTypeComposer>);
    createTypeComposer<T>(constructor: ClassType<T>): ObjectTypeComposer<T>;
    createInputTypeComposer(constructor: ClassType): InputTypeComposer;
}
export interface ComposerInstanceCreator<C extends ObjectTypeComposer | InputTypeComposer | EnumTypeComposer> {
    create(type: ProvidenTypeSingular): C;
    createFromString(text: string): C;
}
export declare class InputComposerCreator implements ComposerInstanceCreator<InputTypeComposer> {
    protected schemaComposer: SchemaComposer<any>;
    protected nameKeeper: TypeNameKeeper;
    protected classSpecialist: ClassSpecialist;
    constructor(schemaComposer: SchemaComposer<any>, nameKeeper: TypeNameKeeper, classSpecialist: ClassSpecialist);
    create(type: ProvidenTypeSingular): InputTypeComposer;
    createFromString(text: string): InputTypeComposer;
}
export declare class CannotCreateTypeComposerFromITC extends GraphqlComposeTypescriptError {
    constructor(itc: InputTypeComposer);
}
export declare class OutputComposerCreator implements ComposerInstanceCreator<ObjectTypeComposer | EnumTypeComposer> {
    protected schemaComposer: SchemaComposer<any>;
    protected nameKeeper: TypeNameKeeper;
    protected classSpecialist: ClassSpecialist;
    constructor(schemaComposer: SchemaComposer<any>, nameKeeper: TypeNameKeeper, classSpecialist: ClassSpecialist);
    create(type: ProvidenTypeSingular): ObjectTypeComposer;
    createFromString(text: string): ObjectTypeComposer;
}
